# chabie

Python comparison utility

## Install

```
pip install chabie
```

### Dictionary


## TODO

- Implement built-in keys(functions) to compare:
      - datetime with given accuracy(by second, minute or date)
      - number with given precision
